timerelationtools.timespan_2_contains_timespan_1_improperly
===========================================================

.. autofunction:: abjad.tools.timerelationtools.timespan_2_contains_timespan_1_improperly.timespan_2_contains_timespan_1_improperly
   :noindex:
